# Usage

from gosmscz import send_batch_sms

```
send_batch_sms(
    client_id: 'vaseId',
    client_secret: 'vaseSecret',
    message: 'Sms zprava k odeslani',
    recipients: ['+420777000111', '+420777222333']
)
```

